@@ -32,6 +32,8 @@ public:
     void setNetworkAccessManager(QNetworkAccessManager *manager);
     int doWebRequest(QString method, QString itemURL, int params);
 
+    void login(QString username, QString password);
+    void loadAllPortfolio();
 
 signals:
 
