@@ -18,8 +18,6 @@
 */
 
 var sid = "";
-var sidToken = "";
-var debug = 0;
 
 // UI components
 var waiting;
@@ -28,13 +26,6 @@ var error;
 var model;
 var pModel;
 
-var continuation = "";
-var actionID = "";
-var actionFeedUrl = ""
-var accessToken = "";
-var action = "";
-var tags = "";
-
 var itemsURL = "";
 var gPfoLength;
 
@@ -148,7 +139,10 @@ function doWebRequest(method, url, params, callback, show) {
         if (doc.readyState == XMLHttpRequest.HEADERS_RECEIVED) {
             var status = doc.status;
             // Ignore 500 error
-            if(status!=200&&status!=500) {
+            if (status==404) {
+                showError("Cannot load portfolio.\nCheck Setting->Portfolio.\nCreate portfolio on Google if\nyou don't have any.", show);
+            }
+            else if (status!=200&&status!=500) {
                 showError("API returned " + status + " " + doc.statusText, show);
             }
         } else if (doc.readyState == XMLHttpRequest.DONE) {
@@ -174,7 +168,6 @@ function doWebRequest(method, url, params, callback, show) {
         doc.setRequestHeader("Authorization", "GoogleLogin auth=" + sid);
         // Specifying a version
         doc.setRequestHeader("GData-Version", "2");
-        //doc.setRequestHeader("Cookie", "SID=" + sidToken);
     }
 
     if(params<2) {
@@ -194,7 +187,10 @@ function doWebRequestIdx(method, url, params, callback, idx, show) {
         if (doc.readyState == XMLHttpRequest.HEADERS_RECEIVED) {
             var status = doc.status;
             // Ignore 500 error
-            if(status!=200&&status!=500) {
+            if (status==404) {
+                showError("Cannot load portfolio.\nCheck Setting->Portfolio.\nCreate portfolio on Google if\nyou don't have any.", show);
+            }
+            else if(status!=200&&status!=500) {
                 showError("Google API returned " + status + " " + doc.statusText, show);
             }
         } else if (doc.readyState == XMLHttpRequest.DONE) {
@@ -251,8 +247,6 @@ function parseAuth(data, parameterName) {
 function parseToken(data) {
     sid = parseAuth(data, "Auth");
     //console.log("Auth=" + sid);
-    //sidToken = parseAuth(data, "SID");
-    //console.log("SID=" + sidToken);
 
     if(sid.length>0) {
         //waiting.state = "hidden";
@@ -302,8 +296,8 @@ function loadAllPortfolios() {
 function loadOnePosition(posFeedLink, pfoLocal, pfoIsYahoo, loadPosFromFile) {
 
     // activePos is not set upon first entry
-    if (activePos=="") {
-        activePos = "https://finance.google.com/finance/feeds/default/portfolios/1/positions";
+    if (posFeedLink=="") {
+        posFeedLink = "https://finance.google.com/finance/feeds/default/portfolios/1/positions";
     }
 
     // Replace http with https
@@ -349,8 +343,6 @@ function loadAllYahooQuote(quoteList, isYahooQuote) {
         itemsURL =   "http://download.finance.yahoo.com/d/quotes.csv?s="+ quoteList + "&f=b2b3";
         loadYahooQuote();
     }
-    //console.log(itemsURL);
-
 }
 
 function loadOnePortfolio(PortfolioName) {
@@ -451,6 +443,7 @@ function loadQuote(symObj, idx) {
 function loadYahooQuote() {
     try {
         waiting.state = "shown";
+        //console.log(itemsURL);
         doWebRequest("GET", itemsURL, 2, parseCSV, 3);
     } catch(err) {
         showError("Error while loading y_quote: " + err, 1);
@@ -595,6 +588,7 @@ function loadLocalPosition(pfoIdx, pfoIsYahoo, loadPosFromFile) {
 
     var fileOk = 0;
 
+    // Only load from file when specified
     if (loadPosFromFile) {
         fileOk = fileHandler.loadPos(pfoIdx);
     }
@@ -637,13 +631,16 @@ function loadLocalPosition(pfoIdx, pfoIsYahoo, loadPosFromFile) {
 
 function parsePosition(data) {
     //try {
-        // 2) XML DOM
         var posLength = data.childNodes[7].firstChild.nodeValue;
 
-        //console.log("pos.length="+posLength);
+        console.log("pos.length="+posLength);
         var quoteList = "";
 
-        // <entry>
+        // Improved error handling
+        if (posLength==0) {
+            showError("Cannot load portfolio.\nCheck Setting->Portfolio.\nCreate portfolio on Google if\nyou don't have any.", 1);
+        }
+        else {
         /*
         Index:5
         <gd:feedLink href='http://finance.google.com/finance/feeds/portfolios/2/positions/NYSE:VNQ/transactions'>
@@ -787,12 +784,14 @@ function parsePosition(data) {
     //    addError("Error: " + err);
     //}
     waiting.state = "hidden";
+        }
 }
 
-// There is a Yahoo real-time feed!
+// Parse Yahoo feed
 function parseCSV(data) {
-    // Array[Row][Column]
     //console.log(data);
+
+    // Array[Row][Column]
     var csvObj = CSVToArray(data);
 
     if (csvObj == "0") {
@@ -838,17 +837,24 @@ function parseCSV(data) {
                  change = change.split(" - ");
                  change[1] = change[1].substr(0, change[1].indexOf("%"));
 
+                 // C function to compute value, gain, day-gain, and gain percentage.
+                 var perfData = "";
+
+                 if (csvObj[i][8]!="N/A") {
+                     perfData = fileHandler.calcPerformance(i, csvObj[i][8]);
+                 }
+
                  if (pModel.count==0) {
                         pModel.append({
                              "exchange":   (csvObj[i][14]=="N/A") ? "-" : csvObj[i][14],
                              "fullName":   (csvObj[i][15]=="N/A") ? "-" : csvObj[i][15],
                              "name":         fileHandler.localPosSymbol[i],
                              "share":        fileHandler.localPosShare[i],
-                             "shareGain":    0,
-                             "shareCost":    fileHandler.localPosCost[i],
-                             "shareDayGain": 0,
-                             "shareValue":   0,
-                             "shareGainPercent": 0,
+                             "shareGain":    perfData[0],
+                             "shareCost":    perfData[1],
+                             "shareDayGain": "-",
+                             "shareValue":   perfData[2],
+                             "shareGainPercent": perfData[3],
 
                              "quoteAsk":   (csvObj[i][0]=="N/A") ? "-" : csvObj[i][0],
                              "quoteBid":   (csvObj[i][1]=="N/A") ? "-" : csvObj[i][1],
